@@ -232,7 +232,7 @@ class HiveTableLastUpdatedExtractor(Extractor):
         LOGGER.info('Extracting partitioned table')
         partitioned_tbl_row = self._partitioned_table_extractor.extract()
         while partitioned_tbl_row:
-            LOGGER.info('table %s:%s time:%s', partitioned_tbl_row['schema'], partitioned_tbl_row['table_name'], partitioned_tbl_row['last_updated_time'])
+            # LOGGER.info('table %s:%s time:%s', partitioned_tbl_row['schema'], partitioned_tbl_row['table_name'], partitioned_tbl_row['last_updated_time'])
             yield TableLastUpdated(table_name=partitioned_tbl_row['table_name'],
                                    last_updated_time_epoch=partitioned_tbl_row['last_updated_time'],
                                    schema=partitioned_tbl_row['schema'],
